Index: include/core/SkMatrix.h |
diff --git a/include/core/SkMatrix.h b/include/core/SkMatrix.h |
index e225336bd845218eea5c91feb4492a929df8aab1..d52ab67f8c968896af88abd163356d232ed364f5 100644 |
--- a/include/core/SkMatrix.h |
+++ b/include/core/SkMatrix.h |
@@ -563,20 +563,20 @@ public: |
SK_TO_STRING_NONVIRT() |
/** |
- * Calculates the minimum stretching factor of the matrix. If the matrix has |
+ * Calculates the minimum scaling factor of the matrix. If the matrix has |
* perspective -1 is returned. |
* |
* @return minumum strecthing factor |
*/ |
- SkScalar getMinStretch() const; |
+ SkScalar getMinScale() const; |
/** |
* Calculates the maximum stretching factor of the matrix. If the matrix has |
* perspective -1 is returned. |
* |
* @return maximum strecthing factor |
*/ |
- SkScalar getMaxStretch() const; |
+ SkScalar getMaxScale() const; |
/** |
* Return a reference to a const identity matrix |
@@ -563,20 +563,20 @@ public: |
* perspective -1 is returned. |
* |
- * @return minumum strecthing factor |
+ * @return minumum scale factor |
*/ |
@@ -563,20 +563,20 @@ public: |
/** |
- * Calculates the maximum stretching factor of the matrix. If the matrix has |
+ * Calculates the maximum scale factor of the matrix. If the matrix has |
* perspective -1 is returned. |
* |
@@ -563,20 +563,20 @@ public: |
* perspective -1 is returned. |
* |
- * @return maximum strecthing factor |
+ * @return maximum scale factor |
*/ |